@@ -191,8 +191,8 @@ static gnc_quote_source single_quote_sources[] =
     { FALSE, 0, 0, "Paris Stock Exchange/Boursorama, FR", "BOURSO", "bourso" },
     { FALSE, 0, 0, "Paris Stock Exchange/LeRevenu, FR", "LEREVENU", "lerevenu" },
     { FALSE, 0, 0, "Platinum Asset Management, AU", "PLATINUM", "platinum" },
-    { FALSE, 0, 0, "SIX funds, CH", "SIXFUNDS", "sixfunds" },
-    { FALSE, 0, 0, "SIX shares, CH", "SIXSHARES", "sixshares" },
+    { FALSE, 0, 0, "SIX Swiss Exchange funds, CH", "SIXFUNDS", "sixfunds" },
+    { FALSE, 0, 0, "SIX Swiss Exchange shares, CH", "SIXSHARES", "sixshares" },
     { FALSE, 0, 0, "Skandinaviska Enskilda Banken, SE", "SEB_FUNDS", "seb_funds" },
     { FALSE, 0, 0, "Sharenet, ZA", "ZA", "za" },
     { FALSE, 0, 0, "StockHouse Canada", "STOCKHOUSE_FUND", "stockhousecanada_fund" },
