@@ -152,7 +152,7 @@ static gboolean gnc_sxed_check_consistent (GncSxEditorDialog2 *sxed);
 static gboolean gnc_sxed_check_changed (GncSxEditorDialog2 *sxed);
 static void gnc_sxed_save_sx (GncSxEditorDialog2 *sxed);
 static void gnc_sxed_freq_changed (GncFrequency *gf, gpointer ud);
-static void sxed_excal_update_adapt_cb (GtkObject *o, gpointer ud);
+static void sxed_excal_update_adapt_cb (GtkWidget *o, gpointer ud);
 static void gnc_sxed_update_cal (GncSxEditorDialog2 *sxed);
 static void on_sx_check_toggled_cb (GtkWidget *togglebutton, gpointer user_data);
 //void on_sx_check_toggled_cb (GtkWidget *togglebutton, gpointer user_data);
@@ -1003,21 +1003,21 @@ gnc_sxed_save_sx (GncSxEditorDialog2 *sxed )
 
 
 static void
-enabled_toggled_cb (GtkObject *o, GncSxEditorDialog2 *sxed)
+enabled_toggled_cb (GtkToggleButton *o, GncSxEditorDialog2 *sxed)
 {
     return;
 }
 
 
 static void
-autocreate_toggled_cb (GtkObject *o, GncSxEditorDialog2 *sxed)
+autocreate_toggled_cb (GtkToggleButton *o, GncSxEditorDialog2 *sxed)
 {
-    if ( !gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(o)))
+    if ( !gtk_toggle_button_get_active (o))
     {
         gtk_toggle_button_set_active (sxed->notifyOpt, FALSE);
     }
     gtk_widget_set_sensitive (GTK_WIDGET (sxed->notifyOpt),
-                              gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(o)));
+                              gtk_toggle_button_get_active (o));
 }
 
 
@@ -1043,7 +1043,7 @@ remind_toggled_cb (GtkButton *o, GncSxEditorDialog2 *sxed)
 
 /* Local destruction of dialog */
 static void
-scheduledxaction_editor_dialog_destroy (GtkObject *object, gpointer data)
+scheduledxaction_editor_dialog_destroy (GtkWidget *object, gpointer data)
 {
     GncSxEditorDialog2 *sxed = data;
 
@@ -1587,9 +1587,14 @@ gnc_sxed_update_cal (GncSxEditorDialog2 *sxed)
                 && g_date_valid (&first_date)
                 && g_date_compare (last_sx_inst, &first_date) != 0)
         {
+            /* last occurrence will be passed as initial date to update store
+             * later on as well */
             start_date = *last_sx_inst;
             recurrenceListNextInstance (recurrences, &start_date, &first_date);
         }
+        else
+            /* move one day back so the store can get the proper first recurrence. */
+            g_date_subtract_days(&start_date, 1);
     }
 
     if (!g_date_valid (&first_date))
@@ -1615,17 +1620,17 @@ gnc_sxed_update_cal (GncSxEditorDialog2 *sxed)
         GDate end_date;
         g_date_clear (&end_date, 1);
         gnc_gdate_set_time64 (&end_date, gnc_date_edit_get_date (sxed->endDateEntry));
-        gnc_dense_cal_store_update_recurrences_date_end (sxed->dense_cal_model, &first_date, recurrences, &end_date);
+        gnc_dense_cal_store_update_recurrences_date_end (sxed->dense_cal_model, &start_date, recurrences, &end_date);
     }
     else if (gtk_toggle_button_get_active (sxed->optEndNone))
     {
-        gnc_dense_cal_store_update_recurrences_no_end (sxed->dense_cal_model, &first_date, recurrences);
+        gnc_dense_cal_store_update_recurrences_no_end (sxed->dense_cal_model, &start_date, recurrences);
     }
     else if (gtk_toggle_button_get_active (sxed->optEndCount))
     {
         gint num_remain
         = gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (sxed->endRemainSpin));
-        gnc_dense_cal_store_update_recurrences_count_end (sxed->dense_cal_model, &first_date, recurrences, num_remain);
+        gnc_dense_cal_store_update_recurrences_count_end (sxed->dense_cal_model, &start_date, recurrences, num_remain);
     }
     else
     {
@@ -1645,7 +1650,7 @@ gnc_sxed_freq_changed (GncFrequency *gf, gpointer ud)
 
 
 static void
-sxed_excal_update_adapt_cb (GtkObject *o, gpointer ud)
+sxed_excal_update_adapt_cb (GtkWidget *o, gpointer ud)
 {
     gnc_sxed_update_cal ((GncSxEditorDialog2*)ud);
 }
