@@ -44,7 +44,6 @@
 
 #include "dialog-utils.h"
 #include "assistant-ab-initial.h"
-#include "assistant-utils.h"
 #include "gnc-ab-kvp.h"
 #include "gnc-ab-utils.h"
 #include "gnc-component-manager.h"
@@ -75,7 +74,7 @@ void aai_on_prepare (GtkAssistant  *assistant, GtkWidget *page,
 
 void aai_on_finish (GtkAssistant *gtkassistant, gpointer user_data);
 void aai_on_cancel (GtkAssistant *assistant, gpointer user_data);
-void aai_destroy_cb(GtkObject *object, gpointer user_data);
+void aai_destroy_cb(GtkWidget *object, gpointer user_data);
 
 gboolean aai_key_press_event_cb(GtkWidget *widget, GdkEventKey *event, gpointer user_data);
 
@@ -151,7 +150,7 @@ enum account_list_cols
 gboolean
 aai_key_press_event_cb(GtkWidget *widget, GdkEventKey *event, gpointer user_data)
 {
-    if (event->keyval == GDK_Escape)
+    if (event->keyval == GDK_KEY_Escape)
     {
         gtk_widget_destroy(widget);
         return TRUE;
@@ -171,7 +170,7 @@ aai_on_cancel (GtkAssistant *gtkassistant, gpointer user_data)
 }
 
 void
-aai_destroy_cb(GtkObject *object, gpointer user_data)
+aai_destroy_cb(GtkWidget *object, gpointer user_data)
 {
     ABInitialInfo *info = user_data;
 
@@ -578,7 +577,8 @@ ab_account_longname(const AB_ACCOUNT *ab_acc)
     bankcode = AB_Account_GetBankCode(ab_acc);
     subAccountId = AB_Account_GetSubAccountId(ab_acc);
 
-    /* Translators: Strings are 1. Account code, 2. Bank name, 3. Bank code. */
+    /* Translators: Strings are 1. Bank code, 2. Bank name,
+     * 3. Account Number,  4. Subaccount ID                  */
     result = g_strdup_printf(_("Bank code %s (%s), Account %s (%s)"),
                              bankcode,
                              bankname ? bankname : "",
@@ -855,8 +855,6 @@ gnc_ab_initial_assistant(void)
 
     info->window = GTK_WIDGET(gtk_builder_get_object (builder, "AqBanking Init Assistant"));
 
-    gnc_assistant_set_colors (GTK_ASSISTANT (info->assistant));
-
     info->api = gnc_AB_BANKING_new();
     info->deferred_info = NULL;
     info->gnc_hash = NULL;
