@@ -714,9 +714,11 @@ gnc_bi_import_create_bis (GtkListStore * store, QofBook * book,
         {
             qof_scan_date (date_opened, &day, &month, &year); // FIXME: Must check for the return value of qof_scan_date!
             gncEntrySetDate(entry, gnc_dmy2timespec (day, month, year));
+            gncEntrySetDateEntered(entry, gnc_dmy2timespec (day, month, year));
         }
         else
         {
+            gncEntrySetDate(entry, today);
             gncEntrySetDateEntered(entry, today);
         }
         // Remove escaped quotes
