@@ -20,12 +20,11 @@
  *                                                                  *
 \********************************************************************/
 
-/*
- * FILE:
- * datecell.h
- *
- * FUNCTION:
- * The DateCell object implements a date handling cell.  It
+/** @addtogroup Cell Cell
+ * @{
+ * @file datecell.h
+ * @struct DateCell
+ * @brief The DateCell object implements a date handling cell.  It
  * is able to display dates in several formats, it is also
  * able to accept date input, and also supports a number of accelerator
  * keys.
@@ -69,22 +68,6 @@
  *
  *
  * METHODS:
- * The xaccSetDateCellValue() method accepts a numeric date and
- *    sets the contents of the date cell to that value.  The
- *    value day, month, year should follow the regular written
- *    conventions, i.e. day==(1..31), mon==(1..12), year==4 digits
- *
- * The xaccCommitDateCell() method commits any pending changes to the
- *    value of the cell.  That is, it will take the cells current string
- *    value, and parse it into a month-day-year value.
- *
- *    Why is this needed? Basically, while the user is typing into the
- *    cell, we do not even try to parse the date, lest we confuse things
- *    royally.  Normally, when the user leaves this cell, and moves to
- *    another, we parse the date and print it nicely and cleanly into
- *    the cell.  But it can happen that we want to get the accurate contents
- *    of the date cell before we've left it, e.g. if the user has clicked
- *    on the "commit" button.  This is the routine to call for that.
  *
  * HISTORY:
  * Copyright (c) 1998, 1999, 2000 Linas Vepstas <linas@linas.org>
@@ -100,23 +83,53 @@
 #include "qof.h"
 
 
-typedef struct date_cell
+typedef struct
 {
     BasicCell cell;
 } DateCell;
 
-/* installs a callback to handle date recording */
+/** installs a callback to handle date recording */
 BasicCell * gnc_date_cell_new (void);
 
-/* days are 1-31, mon is 1-12, year 1900 == 1900 */
+/** Accepts a numeric date and sets the contents of the date cell to that value.
+ * The value day, month, year should follow the regular written conventions.
+ * @param cell The DateCell to set
+ * @param day The day of the month, 1..31
+ * @param month The month of the year, 1..12
+ * @param year The year, 4 digits, common era
+  */
 void        gnc_date_cell_set_value (DateCell *cell,
                                      int day, int mon, int year);
+/** Sets the contents of the cell with seconds before or since the Unix epoch.
+ * @param cell The DateCell to set
+ * @param secs Seconds before or since the Unix epoch, 1 January 1970 CE.
+ */
 void        gnc_date_cell_set_value_secs (DateCell *cell, time64 secs);
 
+/** Commits any pending changes to the value of the cell.  That is, it will take
+ * the cells current string value, and parse it into a month-day-year value.
+ *
+ * Why is this needed? Basically, while the user is typing into the cell, we do
+ * not even try to parse the date, lest we confuse things royally.  Normally,
+ * when the user leaves this cell, and moves to another, we parse the date and
+ * print it nicely and cleanly into the cell.  But it can happen that we want to
+ * get the accurate contents of the date cell before we've left it, e.g. if the
+ * user has clicked on the "commit" button.  This is the routine to call for
+ * that.
+*/
 void        gnc_date_cell_commit (DateCell *cell);
 
+/** Set a Timespec to the value in the DateCell.
+ * @param cell The DateCell
+ * @param ts A Timespec* to which the function will write the date.
+ */
 void        gnc_date_cell_get_date (DateCell *cell, Timespec *ts);
 
-void        gnc_date_cell_get_date_gdate (DateCell *cell, GDate *date);
+/**  Timespec to the value in the DateCell.
+ * @param cell The DateCell
+ * @param date A GDate* into which the functino will write the date.
+ */
 
+void        gnc_date_cell_get_date_gdate (DateCell *cell, GDate *date);
+/** @} */
 #endif
